.. _glossary:

============================
Glossary
============================

.. glossary::

  interface
     A term used by zope.component to indicate a marker describing an
     object.  repoze.configuration does not use interface objects.
  zope.component
     The system from which the ideas in repoze.component are derived.
  repoze.configuration
    A system that allows for the loading of configuration directives
    from `YAML <http://yaml.org>`_ files.  A ``component`` directive
    is included with :mod:`repoze.component` that can be spelled in a
    YAML configuration file when :mod:`repoze.component` is used with
    the ``repoze.configuration`` package.  See
    :ref:`loading_from_a_config_file` for more information.
  YAML
    `YAML Aint Markup Language <http://www.yaml.org/>`_.



